#include "TrivialPrimaryGenerator.hh"

#include "G4Event.hh"
#include "G4ParticleGun.hh"
#include "G4ParticleTable.hh"
#include "G4ParticleDefinition.hh"
#include "globals.hh"


/**
 * Defines the energy, position, and direction of the primary particles which 
 * will be shot at the start of each simulation event. These properties
 * are set to the G4ParticleGun, a helper class, which will then do
 * all the necessary work to register these particle properties to the
 * G4Event.
 */
TrivialPrimaryGenerator::TrivialPrimaryGenerator()
{
  G4int n_particle = 1;
  particleGun = new G4ParticleGun(n_particle);

  G4ParticleTable* particleTable = G4ParticleTable::GetParticleTable();

  // Will shoot only single electrons with a defined energy
  particleGun->SetParticleDefinition(particleTable->FindParticle("e-"));
  particleGun->SetParticleEnergy(1.0*GeV);

  // Will shoot from the center/origin of the geometrical set-up:
  particleGun->SetParticlePosition(G4ThreeVector(0., 0., 0.));
  particleGun->SetParticleMomentumDirection(G4ThreeVector(1.0, 0., 0.));
  
  G4cout << "-- TrivialPrimaryGenerator is constructed." << G4endl;
}

/**
 * Clean-up.
 */
TrivialPrimaryGenerator::~TrivialPrimaryGenerator()
{
  delete particleGun;
  G4cout << "-- TrivialPrimaryGenerator is destructed." << G4endl;
}

/**
 * The GeneratePrimaries method take an instance of a G4Event as argument.
 * The task of the method is to assign a set of primary vertices  to this event.
 * Primary vertices are basically the inital values for particles (number, types,
 * momentum, inital positon) which will then be simulated by G4.
 */
void TrivialPrimaryGenerator::GeneratePrimaries(G4Event* anEvent)
{
  particleGun->GeneratePrimaryVertex(anEvent);
}


