#include "TrivialSimSettings.hh"
#include "G4NistManager.hh"
#include "globals.hh"

#include <string>

using namespace std;

// initialisation of static members
TrivialSimSettings* TrivialSimSettings::instance_ = 0;


/**
 * Returns the singleton pointer to the simulation settings. Always use
 * this method to get access to simulation parameters needed
 * for the detector description, primary generator, etc.
 */
const TrivialSimSettings* const TrivialSimSettings::getSettings()
{
  return getModifiableSettings();
}


/**
 * For internal use only ..
 */
TrivialSimSettings* const TrivialSimSettings::getModifiableSettings()
{
  if ( TrivialSimSettings::instance_ == 0 ) 
    TrivialSimSettings::instance_ = new TrivialSimSettings();

  return TrivialSimSettings::instance_;
}


/**
 * @returns pointer to the material for the target cube 
 */
G4Material *  TrivialSimSettings::getTargetMaterial() const
{
  return targetMaterial_;
}

/**
 * @returns vector of magnetic field strength in G4 internal units
 */
G4ThreeVector TrivialSimSettings::getMagFieldValues() const
{
  return magFieldValues_;
}


/**
 * Defines all default values for the user-configurable parameters
 * of the simulation settings.
 */
TrivialSimSettings::TrivialSimSettings() 
{
  G4NistManager* man = G4NistManager::Instance();
  targetMaterial_ =  man->FindOrBuildMaterial("G4_Pb");

  // No magnetic field as default
  magFieldValues_ = G4ThreeVector(0., 0., 0.);

}



