// Global defintions like physical constants & units
#include "globals.hh"

// GEANT4 
#include "G4ParticleGun.hh"
#include "G4UImanager.hh"
#include "G4UIterminal.hh"
#include "G4UItcsh.hh"
#include "G4VisManager.hh"
#include "G4VisExecutive.hh"

// GEANT4 master and simulation setup, command line for exercises
#include "G4RunManager.hh"

// USER classes
#include "TrivialSimSettings.hh"
#include "TrivialPrimaryGenerator.hh"
#include "TrivialDetector.hh"

///////////////////////////////////////////////////////////////////////
//
//  ATTENTION: here you need to change something .....
//
// --------------------------------------------------------------------

// Inclusion of a trivial and highly incomplete  physics list 
//#include "TrivialPhysics.hh"

// Include the better physics list here!!!
//#include "Header of the standard physics class"
#include "StandardPhysics.hh"
// .. AND make sure, you use this physics list instead of the trivial
// when registering the mandatory physics initialization to the G4 kernel.

//
///////////////////////////////////////////////////////////////////////


// Our own commands which we add to the available commands on the
// G4 command line
#include "TrivialCommandLine.hh"

// Useful utilities
#include "unistd.h"
#include <cstdlib>
#include <string>

using namespace std;

int main(int argc, char** argv) 
{

  // Here we instantiate our TrivialCommandLine. Once this is done, the user 
  // defined commands for the G4 command-line defined in this class are 
  // coupled to the TrivialSettings singleton, i.e. whenever one uses one 
  // of these commands, values in the TrivialSettings singleton are updated.
  TrivialCommandLine* myCommands = new TrivialCommandLine;

  // Instantiate the Run manager of G4. This is the central registration entity
  // of your simulation. Here you have to register the mandatory and optional
  // user initialization and -action hooks.
  G4RunManager * runManager = new G4RunManager;

  // These lines will initialize the G4 vislualization system.
  // Once done, you will have several command line commands to visaulize
  // the detector geometry, simulated tracks, .. .
  G4VisManager* visManager = new G4VisExecutive;
  visManager->Initialize();

  // Instantiate and add the mandatory user initialization hook
  // defining the particles and physics processes for this simulation:

  //////////////////////////////////////////////////////////////////
  // Ups - someone stole one line of code from here ....
    runManager->SetUserInitialization(new StandardPhysics);  
  //
  ///////////////////////////////////////////////////////////////////
    
  
  // Instantiate and register the detector description user hook
  runManager->SetUserInitialization(new TrivialDetector);

  // Instantiate and register the only mandatory user-action: the
  // primary generator. The primary generator will, at the beginning of each
  // simulation event, provide the number of particles and their kinematics
  // which are to be simulated initially by G4.
  runManager->SetUserAction(new TrivialPrimaryGenerator);

  // Get the pointer to the User Interface manager.
  // This UI-pointer can be used to apply G4 commands programmatically
  // (usually, G4 commands are applied interactively on the G4 command line).
  G4UImanager * UI = G4UImanager::GetUIpointer();  

  G4UIsession * session = 0;
  
  // The session is a terminal session with a csh-like command line.
  session = new G4UIterminal(new G4UItcsh);      

  // Go into interactive (command line) mode when no argument is given
  // to the executable, i.e. start a G4 session:
  if(argc==1)
  { 
    
    // Start interactive terminal. After this call, the G4 command line
    // will accept interactive commands. The call will return, once the
    // command "exit" is entered. 
    session->SessionStart();
  }
  else
  // Batch mode, in case an argument is given to the executable. The
  // argument is interpreted as the filename of a G4 macro-file:
  { 
    G4String command = "/control/execute ";
    G4String fileName = argv[1];

    // Execute the macro file.
    UI->ApplyCommand(command+fileName);

    // start an interactive session, in case a 2nd argument was passed
    if (argc==3) {
      session->SessionStart();
    }

  }

  // Clean up the session object..
  delete session;

  // End of our simulation, clean up:
  delete runManager;
  delete myCommands;
  
  return 0;
}
