#include "TrivialPhysics.hh"
#include "G4Electron.hh"

/**
 * Constructor doesn't do anything but printing out some message.
 */
TrivialPhysics::TrivialPhysics()
{
  G4cout << "-- TrivialPhysics constructed." << G4endl;
}

/**
* Destructor doesn't do anything but printing out some message.
*/
TrivialPhysics::~TrivialPhysics()
{
  G4cout << "-- TrivialPhysics destructed" << G4endl;
}


/**
 * Will define only an electron as the only particle type to be
 * used in this trivial simulation program.
 */
void TrivialPhysics::ConstructParticle()
{
  G4Electron::ElectronDefinition();
  G4cout << "-- Only an e- defined for our simulation." << G4endl;
}


/**
 * We will only add the transportation process to the only defined
 * particle - the electron.
 */
void TrivialPhysics::ConstructProcess() 
{
  // This method add the transportation process to each particle
  // that has been declared in the ConstructParticle() method.
  // The transportation process comprises the tracking of a particle
  // according to its momentum and any external electromagnetic field
  // through the various volumes of the detector description.
  // The method AddTransportation() is defined in the base class.
  AddTransportation();
}


/**
 * This method only makes sense if we include the electromagnetic
 * physics processes. It's for experienced user's!
 * <a href="../../../../lec/l3/img26.html" target="_blank">See lectures ff.</a> and the 
 * <a href="../../../../man/g4ug/UsersGuides/ForApplicationDeveloper/html/GettingStarted/particleDef.html#2.4.2" target="_blank">G4 documentation</a> if you want to know further
 * details.
 */
void TrivialPhysics::SetCuts()
{
  // No cuts need to be set, because we don't use any physics
  // processes!
}
