#ifndef csc_EnergyCollector_h
#define csc_EnergyCollector_h

#include "G4VSensitiveDetector.hh"

class G4HCofThisEvent;
class G4Step;
class G4TouchableHistory;

#include <fstream>

/**
 * The EnergyCollector is a "sensitive detector". It's purpose
 * is to collect the energy of a positron created by a
 * pair-production process.
 */
class EnergyCollector : public G4VSensitiveDetector
{

public:

  EnergyCollector();

  ~EnergyCollector();

  /**
   * Called at the beginning of the event ONLY IF the EnergyCollector
   * is also registerd to the G4SDManager - the singleton-manager of
   * G4 taking care of proper hit processing ...
   */
  void Initialize(G4HCofThisEvent*);

  /**
   * Called at the end of each event - to store the information
   * collected during hit processing ONLY IF the EnergyCollector
   * is also registerd to the G4SDManager - the singleton-manager of
   * G4 taking care of proper hit processing ...
   */
  void EndOfEvent(G4HCofThisEvent*);


protected:


  /**
   * Hit processing is called at each G4Step within a volume
   * that has been declared sensitive by passing a pointer
   * to an instance of EnergyCollector.
   */
  G4bool ProcessHits(G4Step*aStep,G4TouchableHistory*ROhist);

  G4double positronEnergy_;
 
  /**
   * A file to store the "hits" processed with this class.
   */
  std::ofstream file_;

};


#endif
